package services;

import model.Order;
import model.Pizza;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import services.impl.OrderService;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

import static org.junit.jupiter.api.Assertions.*;

class OrderServiceTest {
    OrderService service;
    List<Order> orders;
    Order newOrder;

    @BeforeEach
    void setUp() {
        orders = new ArrayList<>(Arrays.asList(
                new Order(
                        "Max Mustermann",
                        new ArrayList<>(Arrays.asList(new Pizza(), new Pizza())),
                        new Date()
                ),
                new Order(
                        "Frau Musterfrau",
                        new ArrayList<>(Arrays.asList(new Pizza(), new Pizza())),
                        new Date()
                )));
        service = new OrderService(orders);
        newOrder = new Order(
                "New Order",
                new ArrayList<>(Arrays.asList(new Pizza(), new Pizza())),
                new Date()
        );
    }

    @AfterEach
    void tearDown() {
    }

    @Test
    void addOrder() {
        assertFalse(service.getAllNonDeliverdOrder().contains(newOrder));
        service.addOrder(newOrder);
        assertTrue(service.getAllNonDeliverdOrder().contains(newOrder));
    }

    @Test
    void removeOrder() {
        assertFalse(service.getAllNonDeliverdOrder().contains(newOrder));
        service.addOrder(newOrder);
        assertTrue(service.getAllNonDeliverdOrder().contains(newOrder));
        service.removeOrder(newOrder);
        assertFalse(service.getAllNonDeliverdOrder().contains(newOrder));
    }

    @Test
    void getAllNonDeliverdOrder() {
        assertEquals(2, service.getAllNonDeliverdOrder().size());
        newOrder.setOrderState(Order.OrderState.DELIVERD);
        service.addOrder(newOrder);
        assertEquals(2, service.getAllNonDeliverdOrder().size());
    }

    @Test
    void getAllDeliverdOder() {
        assertEquals(0, service.getAllDeliverdOrder().size());
        newOrder.setOrderState(Order.OrderState.DELIVERD);
        service.addOrder(newOrder);
        assertEquals(1, service.getAllDeliverdOrder().size());
    }
}