package app;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.io.IOException;

import static org.junit.jupiter.api.Assertions.*;

/**
 * Test class for the PropertyManager
 */
class PropertyManagerTest {

    PropertyManager manager = new PropertyManager();

    /**
     * Before each test read all properties
     * @throws IOException if the file could not be read
     */
    @BeforeEach
    void beforeEach() throws IOException {
        manager.readProperties();
    }

    /**
     * Test reading all the properties
     */
    @Test
    void readProperties() {
        assertDoesNotThrow(() -> manager.readProperties());
    }

    /**
     * Test getting a property
     */
    @Test
    void getProperty() {
        assertEquals("deutsch", manager.getProperty("lang"));
        assertEquals("3.14159265359", manager.getProperty("pi"));
    }

    /**
     * Test editing a property
     */
    @Test
    void changeProperty() {
        manager.changeProperty("lang", "english");
        assertNotEquals("deutsch", manager.getProperty("lang"));
        assertEquals("english", manager.getProperty("lang"));
        assertThrows(IllegalArgumentException.class, () -> manager.changeProperty("notexist", "test"));
    }
}